/*
 * Copyright 2021 Regents of the University of Minnesota.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package edu.umn.biomedicus.rtf.reader;

import edu.umn.biomedicus.rtf.beans.keywords.ControlKeywordsDescription;
import edu.umn.biomedicus.rtf.beans.properties.PropertiesDescription;

import java.util.Map;

public class RtfParserFactory {
  private final ControlKeywordsDescription controlKeywordsDescription;
  private final Map<String, KeywordAction> keywordActionMap;
  private final PropertiesDescription propertiesDescription;

  public RtfParserFactory(ControlKeywordsDescription controlKeywordsDescription,
                          Map<String, KeywordAction> keywordActionMap,
                          PropertiesDescription propertiesDescription) {
    this.controlKeywordsDescription = controlKeywordsDescription;
    this.keywordActionMap = keywordActionMap;
    this.propertiesDescription = propertiesDescription;
  }

  public RtfParser create() {
    Map<String, Map<String, Integer>> properties = propertiesDescription.createProperties();
    RtfState state = new RtfState(properties);
    return new RtfParser(keywordActionMap, state);
  }
}
